@@ -23,6 +23,10 @@ pub fn is_a_color_terminal(out: &Term) -> bool {
         return false;
     }
 
+    if env::var("NO_COLOR").is_ok() {
+        return false;
+    }
+
     match env::var("TERM") {
         Ok(term) => term != "dumb",
         Err(_) => false,
@@ -165,10 +169,14 @@ pub fn read_single_key() -> io::Result<Key> {
                                 if let Some(c3) = c3 {
                                     if c3 == '~' {
                                         match c2 {
+                                            '1' => Ok(Key::Home), // tmux
                                             '2' => Ok(Key::Insert),
                                             '3' => Ok(Key::Del),
+                                            '4' => Ok(Key::End), // tmux
                                             '5' => Ok(Key::PageUp),
                                             '6' => Ok(Key::PageDown),
+                                            '7' => Ok(Key::Home), // xrvt
+                                            '8' => Ok(Key::End),  // xrvt
                                             _ => Ok(Key::UnknownEscSeq(vec![c1, c2, c3])),
                                         }
                                     } else {
@@ -214,6 +222,9 @@ pub fn read_single_key() -> io::Result<Key> {
                     '\n' | '\r' => Key::Enter,
                     '\x7f' => Key::Backspace,
                     '\t' => Key::Tab,
+                    '\x01' => Key::Home,      // Control-A (home)
+                    '\x05' => Key::End,       // Control-E (end)
+                    '\x08' => Key::Backspace, // Control-H (8) (Identical to '\b')
                     _ => Key::Char(c),
                 })
             }
@@ -261,11 +272,9 @@ pub fn key_from_utf8(buf: &[u8]) -> Key {
 
 #[cfg(not(target_os = "macos"))]
 lazy_static::lazy_static! {
-    static ref IS_LANG_UTF8: bool = {
-        match std::env::var("LANG") {
-            Ok(lang) => lang.to_uppercase().ends_with("UTF-8"),
-            _ => false,
-        }
+    static ref IS_LANG_UTF8: bool = match std::env::var("LANG") {
+        Ok(lang) => lang.to_uppercase().ends_with("UTF-8"),
+        _ => false,
     };
 }
 
