@@ -1,4 +1,3 @@
-use std::char;
 use std::cmp;
 use std::env;
 use std::ffi::OsStr;
@@ -9,11 +8,10 @@ use std::mem;
 use std::os::windows::ffi::OsStrExt;
 use std::os::windows::io::AsRawHandle;
 use std::slice;
+use std::{char, mem::MaybeUninit};
 
 use encode_unicode::error::InvalidUtf16Tuple;
 use encode_unicode::CharExt;
-#[cfg(feature = "windows-console-colors")]
-use regex::Regex;
 use winapi::ctypes::c_void;
 use winapi::shared::minwindef::DWORD;
 use winapi::shared::minwindef::MAX_PATH;
@@ -39,6 +37,9 @@ use crate::common_term;
 use crate::kb::Key;
 use crate::term::{Term, TermTarget};
 
+#[cfg(feature = "windows-console-colors")]
+use regex::Regex;
+
 #[cfg(feature = "windows-console-colors")]
 lazy_static::lazy_static! {
     static ref INTENSE_COLOR_RE: Regex = Regex::new(r"\x1b\[(3|4)8;5;(8|9|1[0-5])m").unwrap();
@@ -52,7 +53,7 @@ pub const DEFAULT_WIDTH: u16 = 79;
 pub fn as_handle(term: &Term) -> HANDLE {
     // convert between winapi::um::winnt::HANDLE and std::os::windows::raw::HANDLE
     // which are both c_void. would be nice to find a better way to do this
-    unsafe { ::std::mem::transmute(term.as_raw_handle()) }
+    term.as_raw_handle() as HANDLE
 }
 
 pub fn is_a_terminal(out: &Term) -> bool {
@@ -121,9 +122,8 @@ unsafe fn console_on_any(fds: &[DWORD]) -> bool {
 }
 
 #[inline]
-pub fn terminal_size(_out: &Term) -> Option<(u16, u16)> {
-    // TODO: Use term target for getting size
-    terminal_size::terminal_size().map(|x| ((x.1).0, (x.0).0))
+pub fn terminal_size(out: &Term) -> Option<(u16, u16)> {
+    terminal_size::terminal_size_using_handle(out.as_raw_handle()).map(|x| ((x.1).0, (x.0).0))
 }
 
 pub fn move_cursor_to(out: &Term, x: usize, y: usize) -> io::Result<()> {
@@ -282,7 +282,7 @@ pub fn show_cursor(out: &Term) -> io::Result<()> {
     if let Some((hand, mut cci)) = get_console_cursor_info(as_handle(out)) {
         unsafe {
             cci.bVisible = 1;
-            SetConsoleCursorInfo(hand, &mut cci);
+            SetConsoleCursorInfo(hand, &cci);
         }
     }
     Ok(())
@@ -295,7 +295,7 @@ pub fn hide_cursor(out: &Term) -> io::Result<()> {
     if let Some((hand, mut cci)) = get_console_cursor_info(as_handle(out)) {
         unsafe {
             cci.bVisible = 0;
-            SetConsoleCursorInfo(hand, &mut cci);
+            SetConsoleCursorInfo(hand, &cci);
         }
     }
     Ok(())
@@ -330,6 +330,8 @@ pub fn key_from_key_code(code: INT) -> Key {
         winapi::um::winuser::VK_HOME => Key::Home,
         winapi::um::winuser::VK_END => Key::End,
         winapi::um::winuser::VK_DELETE => Key::Del,
+        winapi::um::winuser::VK_SHIFT => Key::Shift,
+        winapi::um::winuser::VK_MENU => Key::Alt,
         _ => Key::Unknown,
     }
 }
@@ -342,7 +344,7 @@ pub fn read_secure() -> io::Result<String> {
                 break;
             }
             Key::Char('\x08') => {
-                if rv.len() > 0 {
+                if !rv.is_empty() {
                     let new_len = rv.len() - 1;
                     rv.truncate(new_len);
                 }
@@ -361,7 +363,7 @@ pub fn read_single_key() -> io::Result<Key> {
 
     let unicode_char = unsafe { *key_event.uChar.UnicodeChar() };
     if unicode_char == 0 {
-        return Ok(key_from_key_code(key_event.wVirtualKeyCode as INT));
+        Ok(key_from_key_code(key_event.wVirtualKeyCode as INT))
     } else {
         // This is a unicode character, in utf-16. Try to decode it by itself.
         match char::from_utf16_tuple((unicode_char, None)) {
@@ -483,13 +485,28 @@ fn read_key_event() -> io::Result<KEY_EVENT_RECORD> {
 }
 
 pub fn wants_emoji() -> bool {
-    false
+    // If WT_SESSION is set, we can assume we're running in the nne
+    // Windows Terminal.  The correct way to detect this is not available
+    // yet.  See https://github.com/microsoft/terminal/issues/1040
+    env::var("WT_SESSION").is_ok()
 }
 
 /// Returns true if there is an MSYS tty on the given handle.
 pub fn msys_tty_on(term: &Term) -> bool {
     let handle = term.as_raw_handle();
     unsafe {
+        // Check whether the Windows 10 native pty is enabled
+        {
+            let mut out = MaybeUninit::uninit();
+            let res = GetConsoleMode(handle as *mut _, out.as_mut_ptr());
+            if res != 0 // If res is true then out was initialized.
+                && (out.assume_init() & ENABLE_VIRTUAL_TERMINAL_PROCESSING)
+                    == ENABLE_VIRTUAL_TERMINAL_PROCESSING
+            {
+                return true;
+            }
+        }
+
         let size = mem::size_of::<FILE_NAME_INFO>();
         let mut name_info_bytes = vec![0u8; size + MAX_PATH * mem::size_of::<WCHAR>()];
         let res = GetFileInformationByHandleEx(
